#!/bin/sh
#
# gogoc IPv6 TSP client for gogo6
#
# chkconfig:   2345 95 5
# description: TSP is a control protocol used to establish and maintain \
#              static tunnels. The gogoCLIENT is used on the host computer \
#              to connect to a tunnel broker using the TSP protocol and to \
#              get the information for its IPv6 tunnel. When it receives the \
#              information for the tunnel, the gogoCLIENT creates the static \
#              tunnel on its operating system. You can setup a dynamic tunnel \
#              anonymously, but if you want a static prefix you need an \
#              account in Freenet6 \
#              http://gogonet.gogo6.com/page/freenet6-account

### BEGIN INIT INFO
# Provides: gogoc
# Required-Start: $local_fs $network
# Required-Stop: $local_fs $network
# Should-Start: 
# Should-Stop: 
# Default-Start: 2 3 4 5
# Default-Stop: 0 1 6
# Short-Description: IPv6 TSP client for gogo6
# Description: TSP is a control protocol used to establish and maintain \
#              static tunnels. The gogoCLIENT is used on the host computer \
#              to connect to a tunnel broker using the TSP protocol and to \
#              get the information for its IPv6 tunnel. When it receives the \
#              information for the tunnel, the gogoCLIENT creates the static \
#              tunnel on its operating system. You can setup a dynamic tunnel \
#              anonymously, but if you want a static prefix you need an \
#              account in Freenet6 \
#              http://gogonet.gogo6.com/page/freenet6-account
### END INIT INFO

# Source function library.
. /etc/rc.d/init.d/functions

exec="/usr/bin/gogoc"
prog="gogoc"
config="/etc/gogoc/gogoc.conf"

[ -e /etc/sysconfig/$prog ] && . /etc/sysconfig/$prog

lockfile=/var/lock/subsys/$prog

start() {
    [ -x $exec ] || exit 5
    [ -f $config ] || exit 6
    echo -n $"Starting $prog: "
    daemon nohup $exec -f $config $GOGOC_OPTS >/dev/null 2>&1 &
    retval=$?
    echo
    [ $retval -eq 0 ] && touch $lockfile
    return $retval
}

stop() {
    echo -n $"Stopping $prog: "
    killproc $exec -HUP
    retval=$?
    echo
    [ $retval -eq 0 ] && rm -f $lockfile
    return $retval
}

restart() {
    stop
    start
}

reload() {
    restart
}

force_reload() {
    restart
}

rh_status() {
    status $prog
}

rh_status_q() {
    rh_status >/dev/null 2>&1
}


case "$1" in
    start)
        rh_status_q && exit 0
        $1
        ;;
    stop)
        rh_status_q || exit 0
        $1
        ;;
    restart)
        $1
        ;;
    reload)
        rh_status_q || exit 7
        $1
        ;;
    force-reload)
        force_reload
        ;;
    status)
        rh_status
        ;;
    condrestart|try-restart)
        rh_status_q || exit 0
        restart
        ;;
    *)
        echo $"Usage: $0 {start|stop|status|restart|condrestart|try-restart|reload|force-reload}"
        exit 2
esac
exit $?
